@@ -11,8 +11,8 @@ from ftis.common.utils import ignored_keys, create_hash
 class FTISProcess:
     """Class that represents the life cycle of a 'FTIS' execution"""
 
-    def __init__(self, source, folder, mode="chain"):
-        self.folder = Path(folder).expanduser().resolve()
+    def __init__(self, source=None, sink=None, mode="chain"):
+        self.sink = Path(sink).expanduser().resolve()
         self.corpus = source
         self.source = source.items  # FIXME this is confusing
         self.chain = []
@@ -23,15 +23,15 @@ class FTISProcess:
         self.prev_meta = {}
 
     def setup(self):
-        self.folder.mkdir(exist_ok=True, parents=True)
+        self.sink.mkdir(exist_ok=True, parents=True)
 
         # Create a place to store microcached results
-        self.cache = self.folder / ".cache"
+        self.cache = self.sink / ".cache"
         self.cache.mkdir(exist_ok=True)
 
         # Setup logging and meta path
-        self.metapath = self.folder / "metadata.json"
-        logfile_path = self.folder / "logfile.log"
+        self.metapath = self.sink / "metadata.json"
+        logfile_path = self.sink / "logfile.log"
 
         # Read in previous metadata if exists
         try:
@@ -93,9 +93,9 @@ class FTISProcess:
 
     def run(self):
         self.setup()
-        md = "# **** FTIS v1.0.6 ****"
+        md = "# **** FTIS v1.1.0 ****"
         md += f"\n\n**Source: {self.corpus.path}**"
-        md += f"\n\n**Output: {self.folder}**"
+        md += f"\n\n**Sink: {self.sink}**"
         md += "\n\n---------------------"
         md += "\n\nBeginning processing..."
         self.console.print(Markdown(md))
